*     ************************************************************************

      subroutine getdbl( i, val1, val2 )

*     ************************************************************************

*     Purpose :
*     ---------

*     This routine reads the integer I and sets its left
*     part in VAL1 and its right part in VAL2.

*     The two parts of the integer I are limited by 99999.

*     Parameters :
*     ------------

*     i       ( int )

*       input  : integer to read.
*       output : unmodified.

*     val1    ( int )

*       input  : meaningless.
*       output : value in the left part of the integer I.

*     val2    ( int )

*       input  : meaningless.
*       output : value in the right part of the integer I.

*     Routines used :
*     ---------------

*     mod.

*     Programming :
*     -------------

*     D. Tuyttens

*     ========================================================================

*     Routine parameters

      integer   i, val1, val2

*     Internal variables

      integer   maxcy
      parameter ( maxcy = 10**5 )

      val1 = i / maxcy
      val2 = mod(i,maxcy)

      return
      end